@@ -14,10 +14,11 @@ from osgeo import ogr
 from osgeo import osr
 
 from .version import __program__
-from .osm_geometries import OsmBoundary, OsmNode, OsmWay, OsmRelation
+from .osm_geometries import OsmId, OsmBoundary, OsmNode, OsmWay, OsmRelation
 
 class OsmData:
-    def __init__(self, translation, rounding_digits=7, max_points_in_way=1800, add_bounds=False):
+    def __init__(self, translation, rounding_digits=7, max_points_in_way=1800, add_bounds=False, \
+                 start_id=0, is_positive=False):
         self.logger = logging.getLogger(__program__)
 
         # options
@@ -32,6 +33,21 @@ class OsmData:
         self.__ways = []
         self.__relations = []
 
+        OsmId.set_id(start_id, is_positive)
+
+
+    def load_start_id_from_file(self, filename):
+        if filename:
+            if len(self.__nodes) == 0 and len(self.__ways) == 0 and len(self.__relations) == 0:
+                OsmId.load_id(filename)
+            else:
+                self.logger.error("Id can only be set before processing, no file has been loaded")
+
+
+    def save_current_id_to_file(self, filename):
+        if filename:
+            OsmId.save_id(filename)
+
 
     def __get_layer_fields(self, layer):
         layer_fields = []
